===============================
lstree
===============================

.. image:: https://img.shields.io/pypi/v/lstree.svg
        :target: https://pypi.python.org/pypi/lstree

.. image:: https://img.shields.io/travis/shreyas/lstree.svg
        :target: https://travis-ci.org/shreyas/lstree

.. image:: https://readthedocs.org/projects/lstree/badge/?version=latest
        :target: https://readthedocs.org/projects/lstree/?badge=latest
        :alt: Documentation Status


lstree is for ls what pstree is for ps, and some more ...

* Free software: MIT license
* Documentation: https://lstree.readthedocs.org.

Features
--------

* Show a folder (or many, if specified) in tree structure
* Show/hide hidden files 
* Ignore empty directories
* Show (filter for) only certain files
* Ignore certain files/folders

Installation
------------

Use pip to install lstree::

    pip install lstree

